function results = nn_ellipse(Cx,Cy,nn)
% PURPOSE: Obtiene todas las elipses formadas por los nn vecinos mas proximos 
%          a cada punto. 
%          Para cada punto se obtienen todas las elipses con angulo de rotacion de 10:10:180
%          y excentricidades predeterminadas en el vector S
% ---------------------------------------------------
%  USAGE: results = nn_ellipse(Cx,Cy,nn)
%  where: Cx  = Coordenate X - Latitude
%         Cy  = Coordenate Y - Longitude
%         nn  = max number of neinbourg
% ---------------------------------------------------
%  RETURNS: results.nn(p,s).eq = matrix Rxnn donde cada fila tiene los
%  vecinos elipticos mas proximos
%  --------------------------------------------------
% written by:
% Fernando A. Lopez Hernandez, 10/02/2012
% Facultad de C.C. de la Empresa
% Dpto. Metodos Cuantitativos e Inform?ticos
% Universidad Polit?cnica de Cartagena
% E-mail: Fernando.Lopez@upct.es
%%
R=length(Cx);
if R>32767,disp('problemas con int16'),return, end
XX=(repmat(Cx',R,1)-repmat(Cx,1,R));
YY=(repmat(Cy',R,1)-repmat(Cy,1,R));
S=[1 1.5 2 3 4 5 10]; % Diferentes parametros para la forma de las ellipse
%% get the circle
sh=1;
a=1;
b=a*sh;
p=10; %el angulo de rotacion. No es importante para obtener los circulos
angulo=(pi/180)*p;
X=XX.*cos(angulo)+YY.*sin(angulo);
Y=-XX.*sin(angulo)+YY.*cos(angulo);
F=(X/a).^2+(Y/b).^2;
[e1 e2] =sort(F); clear e1
F1=e2((1:R)',:)';
results.nn.eq=int16(F1(:,1:nn));

%% Ellipses
for s=2:6
sh=S(s);
a=1;
b=a*sh;
for p=10:10:180
angulo=(pi/180)*p;
X=XX.*cos(angulo)+YY.*sin(angulo);
Y=-XX.*sin(angulo)+YY.*cos(angulo);
F=(X/a).^2+(Y/b).^2;
[e1 e2] =sort(F); clear e1
F1=e2((1:R)',:)';
results.nne(p/10,s-1).eq=int16(F1(:,1:nn));
end
end
